@@ -1,5 +1,5 @@
 K98 = {
-    'cloud' : dict(
+    "cloud": dict(
         x_0=0.0119,
         y_0=0.00548,
         z_0=-0.00215,
@@ -11,7 +11,7 @@ K98 = {
         γ=0.942,
         μ=0.189,
     ),
-    'band1' : dict(
+    "band1": dict(
         x_0=0.0,
         y_0=0.0,
         z_0=0.0,
@@ -23,7 +23,7 @@ K98 = {
         p=4.0,
         δ_r=1.5,
     ),
-    'band2' : dict(
+    "band2": dict(
         x_0=0.0,
         y_0=0.0,
         z_0=0.0,
@@ -35,7 +35,7 @@ K98 = {
         p=4.0,
         δ_r=1.2,
     ),
-    'band3': dict(
+    "band3": dict(
         x_0=0.0,
         y_0=0.0,
         z_0=0.0,
@@ -47,7 +47,7 @@ K98 = {
         p=4.0,
         δ_r=1.5,
     ),
-    'ring' : dict(
+    "ring": dict(
         x_0=0.0,
         y_0=0.0,
         z_0=0.0,
@@ -58,7 +58,7 @@ K98 = {
         σ_r=0.025,
         σ_z=0.054,
     ),
-    'feature' : dict(
+    "feature": dict(
         x_0=0.0,
         y_0=0.0,
         z_0=0.0,
@@ -71,4 +71,4 @@ K98 = {
         θ=-10.0,
         σ_θ=12.1,
     ),
-}
\ No newline at end of file
+}
